==> pc2m-0.9.10.zip: pc2m-0.9.10/Auth.inc.php <==
<?php

/* -------------------------------------------------------------------------
	!!!This file must be in EUC-JP!!!

	å
	for PC2M Web Content Converter for Mobile Clients
	Copyright (C) 2005-2006 ucb@rcdtokyo.com
	http://www.rcdtokyo.com/pc2m/note/
------------------------------------------------------------------------- */

/* -------------------------------------------------------------------------
	̤Υڡȥ
------------------------------------------------------------------------- */

define('AUTH_TITLE', 'å');

/* -------------------------------------------------------------------------
	åܥǥ

	åܥǥϡHTMLʸreturnǵҤޤ
	ʲƤϡɽݤˤȾѤѴԤޤʳ
	ϰڹԤޤ󡣤ʤüбƤ뤹٤ƤΥ
	ʤѤǤޤ
------------------------------------------------------------------------- */

// ǧڥǡ
$_auth_db = array(

	// 'üIDMD5ϥå' => 'žֹMD5ϥå',

);

if (!isset($_SESSION)) {
	return 'åưƤʤᡢεǽѤǤޤ';
}
if (!isset($_auth_db) or !$_auth_db) {
	return '꤬λƤޤ';
}
if ($local_args['p'] === null or $local_args['i'] === null) {
	return '<form action="'.basename($_SERVER['SCRIPT_NAME']).'" method="post" utn>'.
		(($local_args['d'] !== null and !ENABLE_SESSION_COOKIE)?
			'<input type="hidden" name="'.KEY_PREFIX.'d" value="'.$local_args['d'].'">': null).
		'<input type="hidden" name="'.KEY_PREFIX.'a" value="l">
		<input type="radio" name="'.KEY_PREFIX.'i" value="1" checked>å/Хåå׳<br>
		<input type="radio" name="'.KEY_PREFIX.'i" value="0">Хåå׾õ<br>
		<input type="password" name="'.KEY_PREFIX.'p" size="8" istyle="4"><input type="submit" value="¹">
		</form>
		<p>ХååפõȸߤΥå˴뤿ᡢޤǤCookie䥢ɽʤɤƾǤޤ';
}
if ($client->is_mobile === false or $client->getSerialId() === null or !isset($_SERVER['HTTP_USER_AGENT'])) {
	return 'üIDƤޤ';
}
if (!isset($_auth_db[md5($_SERVER['HTTP_USER_AGENT'].$client->getSerialId())])) {
	return 'üIDפޤ';
}
if ($_auth_db[md5($_SERVER['HTTP_USER_AGENT'].$client->getSerialId())] != md5($local_args['p'])) {
	return 'ѥɤפޤ';
}
$_auth_key = md5($_SERVER['HTTP_USER_AGENT'].
	$client->getSerialId().
	$client->getHostname().
	'1'.
	(ENABLE_SESSION_COOKIE? 1: 0).
	$local_args['p']);
$_session_save_path = realpath(session_save_path()).'/';
$_session_filename = 'sess_'.session_id();
$_backup_filename = 'pc2m_backup_'.$_auth_key;
if ($local_args['i'] === '0') {
	if (!file_exists($_session_save_path.$_backup_filename)) {
		return 'ХååפϤޤ';
	}
	if (false === @unlink($_session_save_path.$_backup_filename)) {
		return 'Хååפξõ˼Ԥ';
	}
	$_SESSION = array();
	if (isset($_COOKIE[session_name()])) {
		setcookie(session_name(), '', time() -42000, '/');
	}
	session_destroy();
	return 'ХååפõߤΥå˴ޤ<br>
		Хååפϥ󥻥뤵ƤޤƳޤǥХååפϹԤޤ';
}
if ($local_args['i'] === '1') {
	if (!file_exists($_session_save_path.$_backup_filename)) {
		$_SESSION['authenticated'] = $_auth_key;
		return 'ХååפϤޤǤΤǡ˥Хååפ򳫻Ϥޤ';
	}
	session_write_close();
	if (false === @copy($_session_save_path.$_backup_filename, $_session_save_path.$_session_filename)) {
		return 'å˼Ԥ';
	}
	session_start();

	$_SESSION['atime'] = time();
	if (isset($_SESSION['www_authenticate'])) {
		unset($_SESSION['www_authenticate']);
	}
	if (isset($_SESSION['history']) and !empty($_SESSION['history'])) {
		if (count($_SESSION['history']) > MAX_HISTORY_KEEP) {
			$_SESSION['history'] = sortMultiArray($_SESSION['history'], 0);
			while (count($_SESSION['history']) > MAX_HISTORY_KEEP) {
				array_pop($_SESSION['history']);
			}
		}
	}
	if (isset($_SESSION['cookies']) and !empty($_SESSION['cookies'])) {
		foreach ($_SESSION['cookies'] as $key => $value) {
			if (!isset($value['expires'])
				or $value['expires'] === null
				or strtotime($value['expires']) < time()) {
				unset($_SESSION['cookies'][$key]);
			}
		}
	}
	return 'åޤ';
}

?>

==> pc2m-0.9.11.zip: pc2m-0.9.11/Auth.inc.php <==
<?php

/* -------------------------------------------------------------------------
	!!!This file must be in EUC-JP!!!

	å
	for PC2M Web Content Converter for Mobile Clients
	Copyright (C) 2005-2006 ucb@rcdtokyo.com
	http://www.rcdtokyo.com/pc2m/note/
------------------------------------------------------------------------- */

/* -------------------------------------------------------------------------
	̤Υڡȥ
------------------------------------------------------------------------- */

define('AUTH_TITLE', 'å');

/* -------------------------------------------------------------------------
	åܥǥ

	åܥǥϡHTMLʸreturnǵҤޤ
	ʲƤϡɽݤˤȾѤѴԤޤʳ
	ϰڹԤޤ󡣤ʤüбƤ뤹٤ƤΥ
	ʤѤǤޤ
------------------------------------------------------------------------- */

// ǧڥǡ
$_auth_db = array(

	// 'üIDMD5ϥå' => 'žֹMD5ϥå',

);

if (!isset($_SESSION)) {
	return 'åưƤʤᡢεǽѤǤޤ';
}
if (!isset($_auth_db) or !$_auth_db) {
	return '꤬λƤޤ';
}
if ($local_args['p'] === null or $local_args['i'] === null) {
	return '<form action="'.basename($_SERVER['SCRIPT_NAME']).'" method="post" utn>'.
		(($local_args['d'] !== null and !ENABLE_SESSION_COOKIE)?
			'<input type="hidden" name="'.KEY_PREFIX.'d" value="'.$local_args['d'].'">': null).
		'<input type="hidden" name="'.KEY_PREFIX.'a" value="l">
		<input type="radio" name="'.KEY_PREFIX.'i" value="1" checked>å/Хåå׳<br>
		<input type="radio" name="'.KEY_PREFIX.'i" value="0">Хåå׾õ<br>
		<input type="password" name="'.KEY_PREFIX.'p" size="8" istyle="4"><input type="submit" value="¹">
		</form>
		<p>ХååפõȸߤΥå˴뤿ᡢޤǤCookie䥢ɽʤɤƾǤޤ';
}
if ($client->is_mobile === false or $client->getSerialId() === null or !isset($_SERVER['HTTP_USER_AGENT'])) {
	return 'üIDƤޤ';
}
if (!isset($_auth_db[md5($_SERVER['HTTP_USER_AGENT'].$client->getSerialId())])) {
	return 'üIDפޤ';
}
if ($_auth_db[md5($_SERVER['HTTP_USER_AGENT'].$client->getSerialId())] != md5($local_args['p'])) {
	return 'ѥɤפޤ';
}
$_auth_key = md5($_SERVER['HTTP_USER_AGENT'].
	$client->getSerialId().
	$client->getHostname().
	'1'.
	(ENABLE_SESSION_COOKIE? 1: 0).
	$local_args['p']);
$_session_save_path = realpath(session_save_path()).'/';
$_session_filename = 'sess_'.session_id();
$_backup_filename = 'pc2m_backup_'.$_auth_key;
if ($local_args['i'] === '0') {
	if (!file_exists($_session_save_path.$_backup_filename)) {
		return 'ХååפϤޤ';
	}
	if (false === @unlink($_session_save_path.$_backup_filename)) {
		return 'Хååפξõ˼Ԥ';
	}
	$_SESSION = array();
	if (isset($_COOKIE[session_name()])) {
		setcookie(session_name(), '', time() -42000, '/');
	}
	session_destroy();
	return 'ХååפõߤΥå˴ޤ<br>
		Хååפϥ󥻥뤵ƤޤƳޤǥХååפϹԤޤ';
}
if ($local_args['i'] === '1') {
	if (!file_exists($_session_save_path.$_backup_filename)) {
		$_SESSION['authenticated'] = $_auth_key;
		return 'ХååפϤޤǤΤǡ˥Хååפ򳫻Ϥޤ';
	}
	session_write_close();
	if (false === @copy($_session_save_path.$_backup_filename, $_session_save_path.$_session_filename)) {
		return 'å˼Ԥ';
	}
	session_start();

	$_SESSION['atime'] = time();
	if (isset($_SESSION['www_authenticate'])) {
		unset($_SESSION['www_authenticate']);
	}
	if (isset($_SESSION['history']) and !empty($_SESSION['history'])) {
		if (count($_SESSION['history']) > MAX_HISTORY_KEEP) {
			$_SESSION['history'] = sortMultiArray($_SESSION['history'], 0);
			while (count($_SESSION['history']) > MAX_HISTORY_KEEP) {
				array_pop($_SESSION['history']);
			}
		}
	}
	if (isset($_SESSION['cookies']) and !empty($_SESSION['cookies'])) {
		foreach ($_SESSION['cookies'] as $key => $value) {
			if (!isset($value['expires'])
				or $value['expires'] === null
				or strtotime($value['expires']) < time()) {
				unset($_SESSION['cookies'][$key]);
			}
		}
	}
	$fs = null;
	if (false !== $fs = filesize($_session_save_path.$_session_filename)) {
		$fs = '('.number_format(round($fs /1000), 1).'KB)';
	}
	return 'åޤ'.$fs;
	
}

?>
